@@ -53,6 +53,7 @@ type Config struct {
 	StartCompact                  bool
 	StartAllTasksView             bool
 	CompactTables                 bool
+	StartFiltering                bool
 }
 
 type Model struct {
@@ -92,11 +93,16 @@ type Model struct {
 	err           error
 }
 
-func InitialModel(c Config) Model {
+func getFirstPage(c Config) nomad.Page {
 	firstPage := nomad.JobsPage
 	if c.StartAllTasksView {
 		firstPage = nomad.AllTasksPage
 	}
+	return firstPage
+}
+
+func InitialModel(c Config) Model {
+	firstPage := getFirstPage(c)
 	initialHeader := header.New(
 		constants.LogoString,
 		c.LogoColor,
@@ -170,7 +176,7 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			}
 			m.getCurrentPageModel().SetLoading(false)
 
-			if m.currentPage.CanBeStart() && len(msg.AllPageRows) == 0 {
+			if m.currentPage.CanBeFirstPage() && len(msg.AllPageRows) == 0 {
 				// oddly, nomad http api errors when one provides the wrong token,
 				// but returns empty results when one provides an empty token
 				m.getCurrentPageModel().SetHeader([]string{"Error"})
@@ -316,9 +322,12 @@ func (m *Model) initialize() error {
 	}
 	m.client = *client
 
+	firstPage := getFirstPage(m.config)
+
 	m.pageModels = make(map[nomad.Page]*page.Model)
-	for k, c := range nomad.GetAllPageConfigs(m.width, m.getPageHeight(), m.config.CopySavePath, m.config.CompactTables) {
-		p := page.New(c)
+	for k, pageConfig := range nomad.GetAllPageConfigs(m.width, m.getPageHeight(), m.config.CompactTables) {
+		startFiltering := m.config.StartFiltering && k == firstPage
+		p := page.New(pageConfig, m.config.CopySavePath, startFiltering)
 		m.pageModels[k] = &p
 	}
 
@@ -357,7 +366,8 @@ func (m *Model) handleKeyMsg(msg tea.KeyMsg) tea.Cmd {
 		saving := m.currentPageViewportSaving()
 		enteringInput := currentPageModel != nil && currentPageModel.EnteringInput()
 		typingQLegitimately := msg.String() == "q" && (addingQToFilter || saving || enteringInput || m.inPty)
-		if !typingQLegitimately || m.err != nil {
+		ctrlCInPty := m.inPty && msg.String() == "ctrl+c"
+		if (!ctrlCInPty && !typingQLegitimately) || m.err != nil {
 			return m.cleanupCmd()
 		}
 	}
@@ -452,6 +462,23 @@ func (m *Model) handleKeyMsg(msg tea.KeyMsg) tea.Cmd {
 			}
 		}
 
+		if key.Matches(msg, keymap.KeyMap.Stats) {
+			if selectedPageRow, err := m.getCurrentPageModel().GetSelectedPageRow(); err == nil {
+				if m.currentPage.ShowsTasks() {
+					taskInfo, err := nomad.TaskInfoFromKey(selectedPageRow.Key)
+					if err != nil {
+						m.err = err
+						return nil
+					}
+					if taskInfo.Running {
+						m.alloc, m.taskName = taskInfo.Alloc, taskInfo.TaskName
+						m.setPage(nomad.StatsPage)
+						return m.getCurrentPageCmd()
+					}
+				}
+			}
+		}
+
 		if key.Matches(msg, keymap.KeyMap.Spec) {
 			if selectedPageRow, err := m.getCurrentPageModel().GetSelectedPageRow(); err == nil {
 				switch m.currentPage {
@@ -650,6 +677,8 @@ func (m Model) getCurrentPageCmd() tea.Cmd {
 		return nomad.FetchLogs(m.client, m.alloc, m.taskName, m.logType, m.config.Log.Offset, m.config.Log.Tail)
 	case nomad.LoglinePage:
 		return nomad.PrettifyLine(m.logline, nomad.LoglinePage)
+	case nomad.StatsPage:
+		return nomad.FetchStats(m.client, m.alloc.ID, m.alloc.Name)
 	default:
 		panic("page load command not found")
 	}
